==> SicoCreditPlus_v1.3.10.zip: SicoCreditPlus/src/Core/Content/Product/ProductExtension.php <==
<?php
/**
 * Created by PhpStorm.
 * User: Philipp.Holzmann
 * Date: 23.01.2020
 * Time: 15:56
 */

namespace SicoCreditPlus\Core\Content\Product;

use Shopware\Core\Content\Product\ProductDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\ApiAware;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Inherited;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToManyAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\OneToManyAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use SicoCreditPlus\Core\Content\SicoCreditPlusCalculatedRate\SicoCreditPlusCalculatedRateDefinition;
use SicoCreditPlus\Core\Content\SicoProductgroup\SicoProductgroupDefinition;
use SicoCreditPlus\Core\Content\SicoProductgroupProducts\SicoProductgroupProductsDefinition;

if ( interface_exists('Shopware\Core\Framework\DataAbstractionLayer\EntityExtensionInterface') ) {
	class ProductExtensionBase implements \Shopware\Core\Framework\DataAbstractionLayer\EntityExtensionInterface {
		public function extendFields(FieldCollection $collection ): void {

		}

		public function getDefinitionClass(): string {
			return ProductDefinition::class;
		}
	}
} else {
	class ProductExtensionBase extends \Shopware\Core\Framework\DataAbstractionLayer\EntityExtension {
		public function extendFields(FieldCollection $collection ): void {

		}

		public function getDefinitionClass(): string {
			return ProductDefinition::class;
		}
	}
}

class ProductExtension extends ProductExtensionBase {
	public function extendFields(FieldCollection $collection): void
	{
		$collection->add(
			(new ManyToManyAssociationField(
				'prodgroups',
				SicoProductgroupDefinition::class,
				SicoProductgroupProductsDefinition::class,
				'product_id',
				'productgroup_id'))->addFlags(new Inherited())
		);
		$collection->add((new OneToManyAssociationField(
			'sicoCreditPlusCalculatedRates',
			SicoCreditPlusCalculatedRateDefinition::class,
			'product_id',
			'id'
		))->addFlags(new Inherited(), new ApiAware()));
	}

	public function getDefinitionClass(): string
	{
		return ProductDefinition::class;
	}

}

==> SicoCreditPlus_v1.4.5.zip: SicoCreditPlus/src/Core/Content/Product/ProductExtension.php <==
<?php
/**
 * Created by PhpStorm.
 * User: Philipp.Holzmann
 * Date: 23.01.2020
 * Time: 15:56
 */

namespace SicoCreditPlus\Core\Content\Product;

use Shopware\Core\Content\Product\ProductDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\ApiAware;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Inherited;
use Shopware\Core\Framework\DataAbstractionLayer\Field\ManyToManyAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\OneToManyAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;
use SicoCreditPlus\Core\Content\SicoCreditPlusCalculatedRate\SicoCreditPlusCalculatedRateDefinition;
use SicoCreditPlus\Core\Content\SicoProductgroup\SicoProductgroupDefinition;
use SicoCreditPlus\Core\Content\SicoProductgroupProducts\SicoProductgroupProductsDefinition;

if ( interface_exists('Shopware\Core\Framework\DataAbstractionLayer\EntityExtensionInterface') ) {
	class ProductExtensionBase implements \Shopware\Core\Framework\DataAbstractionLayer\EntityExtensionInterface {
		public function extendFields(FieldCollection $collection ): void {

		}

		public function getDefinitionClass(): string {
			return ProductDefinition::class;
		}
	}
} else {
	class ProductExtensionBase extends \Shopware\Core\Framework\DataAbstractionLayer\EntityExtension {
		public function extendFields(FieldCollection $collection ): void {

		}

		public function getDefinitionClass(): string {
			return ProductDefinition::class;
		}
	}
}

class ProductExtension extends ProductExtensionBase {
	public function extendFields(FieldCollection $collection): void
	{
		$collection->add(
			(new ManyToManyAssociationField(
				'prodgroups',
				SicoProductgroupDefinition::class,
				SicoProductgroupProductsDefinition::class,
				'product_id',
				'productgroup_id'))->addFlags(new Inherited())
		);
		$collection->add((new OneToManyAssociationField(
			'sicoCreditPlusCalculatedRates',
			SicoCreditPlusCalculatedRateDefinition::class,
			'product_id',
			'id'
		))->addFlags(new ApiAware()));
	}

	public function getDefinitionClass(): string
	{
		return ProductDefinition::class;
	}

}
